Module jsonrpc

Module jsonrpc 

Structs

JsonRpcError
JSON-RPC error structure
JsonRpcRequest
JSON-RPC request structure
JsonRpcResponse
JSON-RPC response structure

Functions

read_next_message
Read a message from a reader supporting both line-delimited JSON and LSP Content-Length framing. Returns (message, is_content_length) where is_content_length indicates whether the message came in with a Content-Length header (LSP-style)
write_response_with_length
Write a JSON-RPC response using Content-Length framing to support LSP-style clients.