Module jsonrpc
do_
memory_
mcp
0.1.31
Module jsonrpc
Module Items
Structs
Functions
In crate do_
memory_
mcp
do_memory_mcp
Module
jsonrpc
Structs

Json
RpcError
JSON-RPC error structure
Json
RpcRequest
JSON-RPC request structure
Json
RpcResponse
JSON-RPC response structure
Functions

read_
next_
message
Read a message from a reader supporting both line-delimited JSON and LSP Content-Length framing. Returns (message, is_content_length) where is_content_length indicates whether the message came in with a Content-Length header (LSP-style)
write_
response_
with_
length
Write a JSON-RPC response using Content-Length framing to support LSP-style clients.